////////////////////////////////////////////////////////////////////////////////////////////////
//                                                                                            //
//                                       WATTO STUDIOS                                        //
//                             Java Code, Programs, and Software                              //
//                                    http://www.watto.org                                    //
//                                                                                            //
//                           Copyright (C) 2004-2010  WATTO Studios                           //
//                                                                                            //
// This program is free software; you can redistribute it and/or modify it under the terms of //
// the GNU General Public License published by the Free Software Foundation; either version 2 //
// of the License, or (at your option) any later versions. This program is distributed in the //
// hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranties //
// of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License //
// at http://www.gnu.org for more details. For updates and information about this program, go //
// to the WATTO Studios website at http://www.watto.org or email watto@watto.org . Thanks! :) //
//                                                                                            //
////////////////////////////////////////////////////////////////////////////////////////////////

package org.watto.program.android.sync.foursquare;

import java.net.URL;
import org.json.JSONObject;


/***********************************************************************************************
Details about a single Foursquare friend
***********************************************************************************************/
public class FoursquareFriend {

  /** The Foursquare user ID **/
  long userID = -1; // Custom Column "UserIdData"
  /** The users first name **/
  String firstName = null;
  /** The users last name **/
  String lastName = null;
  /** The URL to the photo of this user **/
  URL photo = null;
  /** The gender of this user **/
  String gender = null; // Custom Column "GenderData"
  /** The phone number of this user **/
  String phoneNumber = null;
  /** The email address of this user **/
  String emailAddress = null;
  /** The Twitter account of this user **/
  String twitter = null;
  /** The Facebook account of this user **/
  String facebook = null;
  /** The home city of this user **/
  String homeCity = null;
  /** The last location this user checked-in to **/
  String checkin = null;
  /** The last time this user checked-in to a venue **/
  long checkinTime = 0;
  /** The timezone of the last check-in **/
  String checkinTimeZone = null;
  /** The shoutout message that this user game at the last check-in **/
  String shoutout = null;


  /***********************************************************************************************
  Creates a new Foursquare friend from JSON data
  @param friend the JSON data for the friend
  ***********************************************************************************************/
  public FoursquareFriend(JSONObject friend){
    toComponent(friend);
  }


  /***********************************************************************************************
  Creates a new Foursquare friend
  @param userID the Foursquare User ID
  @param firstName the first name of the user
  @param lastName the last name of the user
  @param photo the URL to the photo of this user
  @param gender the gender of the user
  @param homeCity the home city of the user
  ***********************************************************************************************/
  public FoursquareFriend(long userID, String firstName, String lastName, URL photo, String gender, String homeCity){
    this.userID = userID;
    this.firstName = firstName;
    this.lastName = lastName;
    this.photo = photo;
    this.gender = gender;
    this.homeCity = homeCity;
  }


  /***********************************************************************************************
  Gets the last check-in location for this user
  @return the <i>checkin</i>
  ***********************************************************************************************/
  public String getCheckin(){
    return checkin;
  }


  /***********************************************************************************************
  Gets the last check-in time for this user
  @return the <i>checkinTime</i>
  ***********************************************************************************************/
  public long getCheckinTime(){
    return checkinTime;
  }


  /***********************************************************************************************
  Gets the timezone of the last check-in for this user
  @return the <i>checkinTimeZone</i>
  ***********************************************************************************************/
  public String getCheckinTimeZone(){
    return checkinTimeZone;
  }


  /***********************************************************************************************
  Gets the email address of this user
  @return the <i>emailAddress</i>
  ***********************************************************************************************/
  public String getEmailAddress(){
    return emailAddress;
  }


  /***********************************************************************************************
  Gets the Facebook account of this user
  @return the <i>facebook</i> account
  ***********************************************************************************************/
  public String getFacebook(){
    return facebook;
  }


  /***********************************************************************************************
  Gets the first name of this user
  @return the <i>firstName</i>
  ***********************************************************************************************/
  public String getFirstName(){
    return firstName;
  }


  /***********************************************************************************************
  Gets the gender of this user
  @return the <i>gender</i>
  ***********************************************************************************************/
  public String getGender(){
    // Make the first letter of the gender capitalised
    if (gender != null && gender.length() > 0){
      return gender.substring(0,1).toUpperCase() + gender.substring(1);
    }
    return gender;
  }


  /***********************************************************************************************
  Gets the home city of this user
  @return the <i>homeCity</i>
  ***********************************************************************************************/
  public String getHomeCity(){
    return homeCity;
  }


  /***********************************************************************************************
  Gets the last name of this user
  @return the <i>lastName</i>
  ***********************************************************************************************/
  public String getLastName(){
    return lastName;
  }


  /***********************************************************************************************
  Gets the phone number of this user
  @return the <i>phoneNumber</i>
  ***********************************************************************************************/
  public String getPhoneNumber(){
    return phoneNumber;
  }


  /***********************************************************************************************
  Gets the URL for the photo of this user
  @return the <i>photo</i> URL
  ***********************************************************************************************/
  public URL getPhoto(){
    return photo;
  }


  /***********************************************************************************************
  Gets the shoutout message for this user
  @return the <i>shoutout</i> message
  ***********************************************************************************************/
  public String getShoutout(){
    return shoutout;
  }


  /***********************************************************************************************
  Gets the Twitter account of this user
  @return the <i>twitter</i> account
  ***********************************************************************************************/
  public String getTwitter(){
    return twitter;
  }


  /***********************************************************************************************
  Gets the user ID of this user
  @return the <i>userID</i>
  ***********************************************************************************************/
  public long getUserID(){
    return userID;
  }


  /***********************************************************************************************
  Sets the last check-in location for this user
  @param checkin the last check-in location for this user
  ***********************************************************************************************/
  public void setCheckin(String checkin){
    this.checkin = checkin;
  }


  /***********************************************************************************************
  Sets the last check-in time for this user
  @param checkinTime the last check-in time for this user
  ***********************************************************************************************/
  public void setCheckinTime(long checkinTime){
    this.checkinTime = checkinTime;
  }


  /***********************************************************************************************
  Sets the timezone of the last check-in for this user
  @param checkinTimeZone the timezone of the last check-in for this user
  ***********************************************************************************************/
  public void setCheckinTimeZone(String checkinTimeZone){
    this.checkinTimeZone = checkinTimeZone;
  }


  /***********************************************************************************************
  Sets the email address of this user
  @param emailAddress the email address of this user
  ***********************************************************************************************/
  public void setEmailAddress(String emailAddress){
    this.emailAddress = emailAddress;
  }


  /***********************************************************************************************
  Sets the Facebook account of this user
  @param facebook the Facebook account of this user
  ***********************************************************************************************/
  public void setFacebook(String facebook){
    this.facebook = facebook;
  }


  /***********************************************************************************************
  Sets the first name of this user
  @param firstName the first name of this user
  ***********************************************************************************************/
  public void setFirstName(String firstName){
    this.firstName = firstName;
  }


  /***********************************************************************************************
  Sets the gender of this user
  @param gender the gender of this user
  ***********************************************************************************************/
  public void setGender(String gender){
    this.gender = gender;
  }


  /***********************************************************************************************
  Sets the home city of this user
  @param homeCity the home city of this user
  ***********************************************************************************************/
  public void setHomeCity(String homeCity){
    this.homeCity = homeCity;
  }


  /***********************************************************************************************
  Sets the last name of this user
  @param lastName the last name of this user
  ***********************************************************************************************/
  public void setLastName(String lastName){
    this.lastName = lastName;
  }


  /***********************************************************************************************
  Sets the phone number of this user
  @param phoneNumber the phone number of this user
  ***********************************************************************************************/
  public void setPhoneNumber(String phoneNumber){
    this.phoneNumber = phoneNumber;
  }


  /***********************************************************************************************
  Sets the URL to the photo of this user
  @param photo the URL to the photo of this user
  ***********************************************************************************************/
  public void setPhoto(URL photo){
    this.photo = photo;
  }


  /***********************************************************************************************
  Sets the shoutout message for this user
  @param shoutout the last shoutout message for this user
  ***********************************************************************************************/
  public void setShoutout(String shoutout){
    this.shoutout = shoutout;
  }


  /***********************************************************************************************
  Sets the Twitter account of this user
  @param twitter the Twitter account of this user
  ***********************************************************************************************/
  public void setTwitter(String twitter){
    this.twitter = twitter;
  }


  /***********************************************************************************************
  Sets the User ID of this user
  @param userID the User ID of this user
  ***********************************************************************************************/
  public void setUserID(long userID){
    this.userID = userID;
  }


  /***********************************************************************************************
  Populates the FoursquareFriend from JSON data
  @param friend the JSON data for the friend
  ***********************************************************************************************/
  public void toComponent(JSONObject friend){
    try {
      this.userID = friend.optLong("id",-1);
      this.firstName = friend.optString("firstName","");
      this.lastName = friend.optString("lastName","");
      this.photo = new URL(friend.optString("photo",null));
      this.gender = friend.optString("gender","");
      this.homeCity = friend.optString("homeCity","");
    }
    catch (Throwable t) {}

  }

}
